@@ -1,3 +1,5 @@
+#[cfg(not(feature = "previews-image"))]
+use anyhow::anyhow;
 #[cfg(feature = "previews-image")]
 use image::{io::Reader as ImageReader, GenericImageView};
 use std::{cmp, path::Path};
