@@ -468,9 +468,8 @@ pub async fn get_thumbnail(
         let address = Address::decode(&b58_decode(&hash).map_err(ErrorInternalServerError)?)
             .map_err(ErrorInternalServerError)?;
         if let Address::Hash(address_hash) = address {
-            let preview_result = preview_store
-                .get(address_hash)
-                .map_err(error::ErrorInternalServerError)?;
+            let preview_store = preview_store.clone();
+            let preview_result = web::block(move || preview_store.get(address_hash)).await?;
 
             if let Some(preview_path) = preview_result {
                 let mut file = NamedFile::open(&preview_path)?.disable_content_disposition();
