@@ -9,7 +9,7 @@ export function useSWR<D = unknown, E = Error>(
   const error = writable<E | undefined>();
 
   async function doFetch() {
-    let keyString = typeof key === "string" ? key : key();
+    const keyString = typeof key === "string" ? key : key();
     try {
       const response = await fetch(keyString);
       if (response.ok) {
